@@ -116,6 +116,7 @@ static void loqui_receiver_irc_joined_channel_append(LoquiReceiverIRC *receiver,
 
 static void loqui_receiver_irc_reply_welcome(LoquiReceiverIRC *receiver, IRCMessage *msg);
 static void loqui_receiver_irc_reply_names(LoquiReceiverIRC *receiver, IRCMessage *msg);
+static void loqui_receiver_irc_reply_notopic(LoquiReceiverIRC *receiver, IRCMessage *msg);
 static void loqui_receiver_irc_reply_topic(LoquiReceiverIRC *receiver, IRCMessage *msg);
 static void loqui_receiver_irc_reply_endofnames(LoquiReceiverIRC *receiver, IRCMessage *msg);
 static void loqui_receiver_irc_reply_channelmodeis(LoquiReceiverIRC *receiver, IRCMessage *msg);
@@ -470,9 +471,9 @@ static void
 loqui_receiver_irc_command_quit(LoquiReceiverIRC *receiver, IRCMessage *msg)
 {
 	LoquiReceiverIRCPrivate *priv;
-	GList *list;
 	LoquiUser *user;
 	LoquiAccount *account;
+	GList *list;
 
 	priv = receiver->priv;
 	account = loqui_receiver_get_account(LOQUI_RECEIVER(receiver));
@@ -529,6 +530,7 @@ loqui_receiver_irc_command_part(LoquiReceiverIRC *receiver, IRCMessage *msg)
 		if(channel) {
 			loqui_receiver_irc_channel_append(receiver, msg, FALSE, 0, LOQUI_TEXT_TYPE_INFO, _("*** You have left %t (%1)"));
 			loqui_channel_set_is_joined(channel, FALSE);
+			loqui_channel_entry_clear_member(LOQUI_CHANNEL_ENTRY(channel));
 		}
 	} else {
 		loqui_receiver_irc_channel_append(receiver, msg, FALSE, 0, LOQUI_TEXT_TYPE_INFO, _("*** %n has just part %t(%L)"));
@@ -602,13 +604,13 @@ loqui_receiver_irc_command_nick(LoquiReceiverIRC *receiver, IRCMessage *msg)
 	priv = receiver->priv;
 	account = loqui_receiver_get_account(LOQUI_RECEIVER(receiver));
 
-	if(msg->nick == NULL) {
+	if (msg->nick == NULL) {
 		loqui_account_warning(account, _("The message does not contain nick"));
 		return;
 	}
 
 	nick_new = irc_message_get_target(msg);
-	if(nick_new == NULL) {
+	if (nick_new == NULL) {
 		loqui_account_warning(account, _("The NICK message does not contain new nick"));
 		return;
 	}
@@ -618,9 +620,6 @@ loqui_receiver_irc_command_nick(LoquiReceiverIRC *receiver, IRCMessage *msg)
 	if (user)
 		loqui_user_set_nick(user, nick_new);
 
-	if(loqui_account_irc_is_current_nick(LOQUI_ACCOUNT_IRC(account), msg->nick))
-		loqui_user_set_nick(loqui_account_get_user_self(account), nick_new);
-
 	if (!LOQUI_UTILS_IRC_STRING_IS_CHANNEL(msg->nick)) {
 		channel = loqui_account_get_channel_by_identifier(account, msg->nick);
 		if (channel) {
@@ -759,10 +758,8 @@ loqui_receiver_irc_command_mode(LoquiReceiverIRC *receiver, IRCMessage *msg)
 		changer = msg->nick;
 	else if(msg->prefix)
 		changer = msg->prefix;
-	else {
-		loqui_account_warning(account, _("Who can change mode?"));
-		return;
-	}
+	else
+		changer = "the server"; /* NULL prefix assumes the server */
 
 	if(strchr(changer, '%')) {
 		loqui_account_warning(account, _("Nick must not contain '%%'"));
@@ -855,13 +852,16 @@ loqui_receiver_irc_reply_welcome(LoquiReceiverIRC *receiver, IRCMessage *msg)
 	LoquiReceiverIRCPrivate *priv;
 	const gchar *autojoin;
 	LoquiAccount *account;
-
+	
         g_return_if_fail(receiver != NULL);
         g_return_if_fail(LOQUI_IS_RECEIVER_IRC(receiver));
 
 	priv = receiver->priv;
 	account = loqui_receiver_get_account(LOQUI_RECEIVER(receiver));
 
+	/* set the string of target to the 'user_self' */
+	loqui_user_set_nick(loqui_account_get_user_self(account), irc_message_get_target(msg));
+	
 	receiver->passed_welcome = TRUE;
 
 	autojoin = loqui_profile_account_irc_get_autojoin(LOQUI_PROFILE_ACCOUNT_IRC(loqui_account_get_profile(account)));
@@ -898,6 +898,9 @@ loqui_receiver_irc_reply_welcome(LoquiReceiverIRC *receiver, IRCMessage *msg)
 	}
 
 	loqui_receiver_irc_account_console_append(receiver, msg, LOQUI_TEXT_TYPE_INFO, "*** %*1");
+	
+	/* reset reconnect count */
+	account->reconnect_try_count = 0;
 }
 static void
 loqui_receiver_irc_reply_names(LoquiReceiverIRC *receiver, IRCMessage *msg)
@@ -1177,6 +1180,28 @@ loqui_receiver_irc_reply_who(LoquiReceiverIRC *receiver, IRCMessage *msg)
 
 	g_free(realname);
 }
+static void
+loqui_receiver_irc_reply_notopic(LoquiReceiverIRC *receiver, IRCMessage *msg)
+{
+	LoquiChannel *channel;
+	gchar *topic;
+	gchar *name;
+	LoquiAccount *account;
+
+        g_return_if_fail(receiver != NULL);
+        g_return_if_fail(LOQUI_IS_RECEIVER_IRC(receiver));
+
+	account = loqui_receiver_get_account(LOQUI_RECEIVER(receiver));
+	
+	name = irc_message_get_param(msg, 1);
+	channel = loqui_account_get_channel_by_identifier(account, name);
+	if (channel == NULL)
+		return;
+
+	loqui_channel_entry_set_topic(LOQUI_CHANNEL_ENTRY(channel), NULL);
+	loqui_receiver_irc_channel_append(receiver, msg, FALSE, 1, LOQUI_TEXT_TYPE_INFO, _("*** No topic is set for %1"));
+}
+
 static void
 loqui_receiver_irc_reply_topic(LoquiReceiverIRC *receiver, IRCMessage *msg)
 {
@@ -1395,6 +1420,9 @@ loqui_receiver_irc_reply(LoquiReceiverIRC *receiver, IRCMessage *msg)
 	case IRC_RPL_TOPICWHOTIME:
 		loqui_receiver_irc_reply_topicwhotime(receiver, msg);
 		return TRUE;
+	case IRC_RPL_NOTOPIC:
+		loqui_receiver_irc_reply_notopic(receiver, msg);
+		return TRUE;
 	case IRC_RPL_TOPIC:
 		loqui_receiver_irc_reply_topic(receiver, msg);
 		return TRUE;
